摩登时代 (豆瓣)
Description: 摩登时代电影简介和剧情介绍,摩登时代影评、图片、预告片、影讯、论坛、在线购票
Keywords: 摩登时代,Modern Times,摩登时代影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.87豆瓣电影Top250

# 摩登时代 Modern Times (1936)

导演: 查理·卓别林
编剧: 查理·卓别林
主演: 查理·卓别林 / 宝莲·高黛 / 亨利·伯格曼 / 蒂尼·桑福德 / 切斯特·康克林 / 汉克·曼 / 斯坦利·布莱斯通 / 阿尔·欧内斯特·加西亚 / 理查德·亚历山大 / 塞西尔·雷诺兹 / 米拉·麦金尼 / 默多克·麦夸里 / 威尔弗雷德·卢卡斯 / 爱德华·勒桑 / 弗雷德·马拉泰斯塔 / 萨米·斯坦 / 特德·奥利弗 / 诺曼·安斯利 / 博比·巴伯 / 海尼·康克林 / 格洛丽亚·德黑文 / 帕特·弗莱厄蒂 / 弗兰克·哈格尼 / 帕特·哈蒙 / 劳埃德·英格拉哈姆 / 沃尔特·詹姆斯 / 爱德华·金博尔 / 杰克·洛 / 巴迪·梅辛杰 / 布鲁斯·米切尔 / 弗兰克·莫兰 / 詹姆斯·C·莫顿 / 路易·纳托 / J·C·纽金特 / 拉斯·鲍威尔 / 约翰兰德 / 哈里·威尔逊
类型: 剧情 / 喜剧 / 爱情
制片国家/地区: 美国
语言: 英语
上映日期: 1936-02-25(美国)
片长: 87分钟
又名: The Masses / Les Temps modernes
IMDb: tt0027977
豆瓣评分
引用
9.3
283657人评价
5星
70.7%
4星
25.2%
3星
3.7%
2星
0.2%
1星
0.1%
好于 99% 喜剧片
好于 99% 剧情片
想看 看过
评价:
推荐

## 摩登时代的剧情简介 · · · · · ·

二十年代的美国处于经济萧条时期，失业率居高不下，工人受尽压榨，成为了大机器生产中的一颗螺丝钉。查理（查理·卓别林 Charles Chaplin 饰）就是一个底层市民，他在一个机器隆隆的厂房里日以继夜地工作，以赚取微薄的收入。重复繁重的工作压得他喘不过气，他把人们的鼻子当成螺丝钉来拧，卷入流水线机器的皮带里，令人苦笑不得。
查理尽管贫穷，但却很善良。他在路上搭救了流浪女，和她一起生活，家里破烂却又温馨。每次身无分文的查理为了找到吃的，都会故意犯事，以便进入监牢。光景一时间有了好转，流浪女成了歌舞红星，然而好景太短暂了。 ©豆瓣

## 摩登时代的演职员 · · · · · · ( 全部 39 )

- 查理·卓别林 导演
- 查理·卓别林 饰 A Factory Worker
- 宝莲·高黛 饰 A Gamin
- 亨利·伯格曼 饰 Cafe Proprietor
- 蒂尼·桑福德 饰 Big Bill
- 切斯特·康克林 饰 Mechanic

## 摩登时代的视频和图片 · · · · · · ( 预告片1 | 添加视频评论 | 图片532 · 添加 )

## 喜欢这部电影的人也喜欢 · · · · · ·

  疯狂的石头

  两杆大烟枪

  让子弹飞

  低俗小说

  大佛普拉斯

  荒蛮故事

  布达佩斯大饭店

  驴得水

  鬼子来了

  奇爱博士

我要写短评

## 摩登时代的短评 · · · · · · ( 全部 47376 条 )

热门 / 最新 / 好友

### 2243 有用 思阳 看过 2009-07-08 08:47:38

惭愧死了，这才是我第一次真正看卓别林的电影。在放映之前我还想，为什么人们要叫他“大师”？不就是一个演员么。结果几秒以后，字幕上映，导演，编剧，主演，甚至音乐配乐都是卓别林创作的。我完全被震撼，真的是大师啊…… 这是一部又辛酸又喜剧的片子，对当时的社会不论是在工业，政治，还是生活

### 1115 有用 托尼·王大拿 看过 2011-09-23 08:03:16

人的异化，极富前瞻性，即使放在今天看了依旧有着强烈的现实意义；卓别林是个极为矛盾的个体：一方面，他总是对社会那些最深入肌理的顽疾给予毫不留情的讽刺和抨击；另一方面，他也是个执拗的人性本善论者。

### 1486 有用 大头绿豆 看过 2005-11-28 01:39:58

靠，看了才知道，星爷有那么多东西是从这里学来的。

### 491 有用 大奇特(Grinch) 看过 2010-03-05 11:33:59

这是卓别林第一部有声片，他尽可能写一个对话剧本，尽可能尝试一次“声音”的实验，然而由于卓别林坚持一贯的“流浪汉”角色，“声音”似乎又与角色不协调。反观，声音又以一种独特的方式呈现，我们听到的机械设备（有声）对人的打压（无声）正符合了电影主题的象征。

### 524 有用 同志亦凡人中文站 看过 2014-04-14 11:08:20

如果电影不曾有过卓别林，该会是一个多么无趣的世界。光前30分钟就让我几度笑岔了气。荒谬有理，喜谑至极！

> 更多短评 47376条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 摩登时代的影评 · · · · · · ( 全部 538 条 )

热门 / 最新 / 好友
baboerben 2007-12-19 15:19:13

## 最好的时代，最坏的时代

卓别林无疑是上个世纪最伟大的电影大师之一，他的作品深深的影响了一代又一代的人。 《摩登时代》可以说是卓别林的代表作，正向片语说的那样“本片讲述工业时代，个人企业与人类追求幸福的冲突”。即使在七十多年后的今天，我在看影片时，同样产生了很多共鸣。 男主人公夏尔洛... (展开)
1032 46 83回应 收起
daangel 2010-07-07 19:19:51

## 男女主角是真的相爱哦——宝莲·高黛小传

看完一查才发现，卓别林真的爱上了宝莲·高黛。怪不得看起来那么动人和自然，打动人心。他俩出现在任何一个镜头里，给人的感觉都是甜蜜的。也算是艺术婚姻，可惜只维持了六年。 宝莲·高黛(1910-1990) 　　宝莲·高黛是三十年代最著名的演员之一,她曾是卓别林的第三任妻子,也... (展开)
516 13 67回应 收起
卡尔维诺J 2009-03-11 01:02:25

## 小丑和绅士 荒诞和真实

这篇影评可能有剧透

（电影课作业） 《摩登时代》是查理卓别林标签式的代表作之一。影片依托于上世纪20-30年代资本主义世界发生的经济大萧条，正如影片开头的字幕揭示的：“本片讲述工业时代，个人企业与人类追求幸福的冲突”。电影放大了在动荡中不可阻挡的现实条件下小人物卑微的生存处境，是对... (展开)
404 11 12回应 收起
Pacino 2012-04-24 12:02:16

## 评摩登时代

一，摩登时代（卓别林） 1，片头出现羊群，随后出现人群。两者形成对照，暗示工人如牲口，唯有待剥。 2，镜头转入工厂。资本家无所事事，拼图，看报，聊以度日。 3，流水线工艺的发明，在加快工作效率的同时，也大大加快工人被剥削的速度。片中的流水线速度被夸张，加强了对资... (展开)
243 18 24回应 收起
泥鳅也是蛇 2015-10-28 17:16:28

## 笑中带泪的社会喜剧

《摩登时代》是卓别林的第七十五部影片，也是他最后一步无声片，最后一步流浪汉影片，从影片的题旨和创作思想是来看，该片是卓别林对于社会，人生及电影艺术的一贯思考的延续和发展。 1、该片延续了同情劳动人民的叙事语态，深刻地揭示了资本主义把人变成机器，变成零件的罪恶 ... (展开)
85 8 4回应 收起
洋洋想吃糖 2018-05-21 16:18:49

## 永远的喜剧大师

《摩登时代》是卓别林最后一部无声电影，是一部非常优秀的作品。影片拍摄于1936年，众所周知，1929—1933年的资本主义世界发生的经济危机，是有史以来资本主义世界最严重的一次，这次经济危机深刻动摇了资本主义经济体制的根基，与此同时，资本主义世界也从自由竞争阶段逐渐过... (展开)
74 6 2回应 收起
你踩着我肥皂了 2018-05-21 18:15:49

## 不朽巨作

黑白的影像却呈现出了现实社会工业化对人的摧残以最为深刻的着点，《摩登时代》那深赋意蕴的荒诞，是查理·卓别林以犀利的演绎对资本工业恶面发出的讥嘲，无论任时代更迭，这都是一部充满摩登气息的作品，因为这就是属于我们的故事。 卓别林总是用喜剧形式包装心酸，走马观花或... (展开)
47 1 0回应 收起
A班江直树 2017-06-10 18:14:40

## 经典

这篇影评可能有剧透

有人说《城市之光》是卓别林最后一部无声电影，但我依然认为这部《摩登时代》才是卓别林默片时代最后的收尾之作。现在回顾《摩登时代》的拍摄年代，我们不得不佩服卓别林的强大。此部影片摄制于1935年，这时好莱坞已经是有声电影的天下，无声电影已经濒临退出历史舞台的边缘，... (展开)
25 0回应 收起
猫七 2017-05-19 22:12:20

## 资本主义的奴隶 幽默背后的悲哀

乍一看“摩登时代”，在我的脑海中首先冒出来的就是英语单词“Modern Time”，而在我们现在人的眼中，“摩登”似乎就是“时尚”、“现代”、“潮流”的代名词。它与舒适、奢侈、高贵的生活状态相联系，但是在1936年拍摄完成的《摩登时代》中，此“摩登”又非彼“摩登”。在看完... (展开)
52 1 0回应 收起
pəteto 2007-11-03 06:53:35

## 一些人在迷失，一些人在满怀希望的做美梦

在youtube上一口气把这部片子看完了。 冲着贫穷者与无产阶级、资本主义的主题去看的，片子也确实反映了这个问题。 资本家们开工厂，流水作业，加快进度，工人们都是单调的重复同样的工作。 卓别林饰演的是一个普通的有些疯狂的小工人。 由于机械化的工作而产生了种种搞笑的事情... (展开)
53 11 12回应 收起

> 更多影评 538篇

添加新讨论

## 讨论区 · · · · · ·

这部电影中，主人公在工厂里干活的段落的主题，有... | 来自大家好我真名叫 | 3 回应 | 2022-11-14 21:54:42
豆瓣还能信吗？ | 来自丿朱朱茵茵 | 12 回应 | 2022-10-31 10:54:06
为什么卓别林在当餐厅服务员时，给人上奶酪，要先... | 来自缨枪 |  | 2022-10-21 21:26:08
经典喜剧电影 | 来自万能的咖啡 |  | 2022-10-15 16:07:05
管理学老师布置作业了... | 来自幻想家 | 3 回应 | 2022-10-12 07:59:03

> 去这部影片的讨论区（全部81条）

## 关于《摩登时代》的问题 · · · · · · ( 全部5个 )

- 为什么片名叫做 摩登年代？ 3人回答
- 我想问一下女主的妹妹后来去哪啦？ 2人回答

> 全部5个问题

## 在哪儿看这部电影 · · · · · ·

- 咪咕视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 爱奇艺视频 VIP免费观看
- 优酷视频 VIP免费观看
- 1905电影网 免费观看
- 哔哩哔哩 免费观看

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 《电影手册》世上最美的100部电影 (大旗虎皮)
- 同时入选IMDB250和豆瓣电影250的电影 (东方快车)
- 有生之年非看不可的1001部电影 (Viking)
- ｜五颗星经典系列｜电影｜ (蜜蜂)

## 谁在看这部电影 · · · · · ·

- -阿怪
  3分钟前 看过
- DerronSong
  3分钟前 看过
- 264726162
  8分钟前 看过

519655人看过 / 219102人想看

订阅摩登时代的评论:
feed: rss 2.0